/**
 ******************************************************************************
 * @file    lis331dlh.h
 * @author  Radek Kysilka
 * @version V1.0.0
 * @date    14-February-2018
 * @brief   LIS331DLH header driver file
 ******************************************************************************
 * @attention
 *
 *
 ******************************************************************************
 */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __LIS331DLH__H
#define __LIS331DLH__H

#ifdef __cplusplus
extern "C" {
#endif
  
/* Includes ------------------------------------------------------------------*/
#include "../Common/accelero.h"


/************** Who am I  *******************/

#define LIS331DLH_ACC_WHO_AM_I           0x32

/************** Device Register  *******************/

#define LIS331DLH_ACC_WHO_AM_I_REG		0x0F
#define LIS331DLH_ACC_CTRL_REG1			0x20
#define LIS331DLH_ACC_CTRL_REG2			0x21
#define LIS331DLH_ACC_CTRL_REG3			0x22
#define LIS331DLH_ACC_CTRL_REG4			0x23
#define LIS331DLH_ACC_CTRL_REG5			0x24
#define LIS331DLH_ACC_CTRL_REG6			0x25
#define LIS331DLH_HP_FILTER_RESER		0x26
#define LIS331DLH_ACC_STATUS_REG		0x27
#define LIS331DLH_ACC_OUT_X_L			0x28
#define LIS331DLH_ACC_OUT_X_H			0x29
#define LIS331DLH_ACC_OUT_Y_L			0x2A
#define LIS331DLH_ACC_OUT_Y_H			0x2B
#define LIS331DLH_ACC_OUT_Z_L			0x2C
#define LIS331DLH_ACC_OUT_Z_H			0x2D
#define LIS331DLH_ACC_INT1_CFG			0x30
#define LIS331DLH_ACC_INT1_SRC			0x31
#define LIS331DLH_ACC_INT1_THS			0x32
#define LIS331DLH_ACC_INT1_DURATION		0x33
#define LIS331DLH_ACC_INT2_CFG			0x34
#define LIS331DLH_ACC_INT2_SRC			0x35
#define LIS331DLH_ACC_INT2_THS			0x36
#define LIS331DLH_ACC_INT2_DURATION		0x37

/* Accelero AXEs selection */
#define LIS331DLH_ACC_X_AXIS_ENABLED		((uint8_t)0x01) /* X enabled */
#define LIS331DLH_ACC_Y_AXIS_ENABLED		((uint8_t)0x02) /* Y enabled */
#define LIS331DLH_ACC_Z_AXIS_ENABLED		((uint8_t)0x04) /* Z enabled */
#define LIS331DLH_ACC_ALL_AXIS_ENABLED		((uint8_t)0x07) /* XYZ enabled */

/* Accelero Full Scale Sensitivity */
#define LIS331DLH_ACC_SENSITIVITY_2G     ((float)1.0f)  /*!< accelerometer sensitivity with 2 g full scale  [mgauss/LSB] */
#define LIS331DLH_ACC_SENSITIVITY_4G     ((float)2.0f)  /*!< accelerometer sensitivity with 4 g full scale  [mgauss/LSB] */
#define LIS331DLH_ACC_SENSITIVITY_8G     ((float)3.9f)  /*!< accelerometer sensitivity with 8 g full scale  [mgauss/LSB] */


/* Accelero Full_ScaleSelection */
#define LIS331DLH_ACC_FULLSCALE_BITPOSITION      ((uint8_t)0x30)  /*!< Output Data Rate bit position */
#define LIS331DLH_ACC_FULLSCALE_2G               ((uint8_t)0x00) /*!< 2 g */
#define LIS331DLH_ACC_FULLSCALE_4G               ((uint8_t)0x10) /*!< 4 g */
#define LIS331DLH_ACC_FULLSCALE_8G               ((uint8_t)0x30) /*!< 8 g */

/* Output Data Rate */
#define LIS331DLH_ACC_ODR_BITPOSITION     ((uint8_t)0x18)  /*!< Output Data Rate bit position      */
#define LIS331DLH_ACC_ODR_50Hz             ((uint8_t)0x00) /* 50 Hz  */
#define LIS331DLH_ACC_ODR_100Hz            ((uint8_t)0x08) /* 100 Hz */
#define LIS331DLH_ACC_ODR_400Hz            ((uint8_t)0x10) /* 400 Hz */
#define LIS331DLH_ACC_ODR_1000Hz           ((uint8_t)0x18) /* 1 kHz */

#define LIS331DLH_ACC_POWERMODE_BITPOSITION ((uint8_t)0xE0)
#define LIS331DLH_ACC_POWER_DOWN			((uint8_t)0x00)
#define LIS331DLH_ACC_POWER_NORMAL			((uint8_t)0x20)

/* Block Data Update */
#define LIS331DLH_BDU_CONTINUOS               ((uint8_t)0x00)
#define LIS331DLH_BDU_BLOCK_UPDATE            ((uint8_t)0x80)

/* Auto-increment */
#define LIS331DLH_ACC_IF_INC_DISABLED    ((uint8_t)0x00)
#define LIS331DLH_ACC_IF_INC_ENABLED     ((uint8_t)0x04)
  
void    LIS331DLH_AccInit(uint16_t InitStruct);
void    LIS331DLH_AccDeInit(void);
uint8_t LIS331DLH_AccReadID(void);
void    LIS331DLH_AccLowPower(uint16_t status);
void    LIS331DLH_AccReadXYZ(int16_t* pData);

extern ACCELERO_DrvTypeDef Lis331dlhAccDrv;

/* IO functions */
extern void     SENSOR_IO_Init(void);
extern void     SENSOR_IO_Write(uint8_t Addr, uint8_t Reg, uint8_t Value);
extern uint8_t  SENSOR_IO_Read(uint8_t Addr, uint8_t Reg);
extern uint16_t SENSOR_IO_ReadMultiple(uint8_t Addr, uint8_t Reg, uint8_t *Buffer, uint16_t Length);
extern void     SENSOR_IO_WriteMultiple(uint8_t Addr, uint8_t Reg, uint8_t *Buffer, uint16_t Length);
/**
  * @}
  */

#ifdef __cplusplus
}
#endif

#endif 
/* __LIS331DLH__H */
