/* Includes ------------------------------------------------------------------*/
#include "humsense.h"

/** @addtogroup BSP
  * @{
  */ 

/** @addtogroup STM32L475E_IOT01
  * @{
  */

/** @defgroup STM32L475E_IOT01_HUMIDITY HUMIDITY
  * @{
  */

/** @defgroup STM32L475E_IOT01_HUMIDITY_Private_Variables HUMIDITY Private Variables 
  * @{
  */ 
static HSENSOR_DrvTypeDef *Hsensor_drv;  
/**
  * @}
  */

/** @defgroup STM32L475E_IOT01_HUMIDITY_Private_Functions HUMIDITY Private Functions
  * @{
  */ 

/**
  * @brief  Initializes peripherals used by the I2C Humidity Sensor driver.
  * @retval HSENSOR status
  */
uint32_t BSP_HSENSOR_Init(void)
{
  uint32_t ret;
  
  if(SHT31DIS_H_Drv.ReadID(SHT31DIS_I2C_ADDRESS) != SHT31DIS_WHO_AM_I_VAL)
  {
    ret = HSENSOR_ERROR;
  }
  else
  {
    Hsensor_drv = &SHT31DIS_H_Drv;
    /* HSENSOR Init */   
    Hsensor_drv->Init(SHT31DIS_I2C_ADDRESS);
    ret = HSENSOR_OK;
  }
  
  return ret;
}

/**
  * @brief  Read ID of SHT31DIS.
  * @retval SHT31DIS ID value.
  */
uint8_t BSP_HSENSOR_ReadID(void)
{ 
  return Hsensor_drv->ReadID(SHT31DIS_I2C_ADDRESS);
}

/**
  * @brief  Read Humidity register of SHT31DIS.
  * @retval SHT31DIS measured humidity value.
  */
float BSP_HSENSOR_ReadHumidity(void)
{ 
  return Hsensor_drv->ReadHumidity(SHT31DIS_I2C_ADDRESS);
}
/**
  * @}
  */

/**
  * @}
  */

/**
  * @}
  */

/**
  * @}
  */
/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
